You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@flex.apache.org by er...@apache.org on 2014/04/15 13:55:07 UTC

[2/2] git commit: [flex-falcon] [refs/heads/develop] - FLEX-34224 use '-output' valued as target directory when specified

FLEX-34224 use '-output' valued as target directory when specified

Signed-off-by: Erik de Bruin <er...@ixsoftware.nl>


Project: http://git-wip-us.apache.org/repos/asf/flex-falcon/repo
Commit: http://git-wip-us.apache.org/repos/asf/flex-falcon/commit/285da92d
Tree: http://git-wip-us.apache.org/repos/asf/flex-falcon/tree/285da92d
Diff: http://git-wip-us.apache.org/repos/asf/flex-falcon/diff/285da92d

Branch: refs/heads/develop
Commit: 285da92d7239f3178ac493b8f7eed8db75c9a9cc
Parents: b39d5e3
Author: Erik de Bruin <er...@ixsoftware.nl>
Authored: Tue Apr 15 13:47:52 2014 +0200
Committer: Erik de Bruin <er...@ixsoftware.nl>
Committed: Tue Apr 15 13:47:52 2014 +0200

----------------------------------------------------------------------
 .../codegen/mxml/flexjs/MXMLFlexJSPublisher.java      | 14 +++++++++++---
 1 file changed, 11 insertions(+), 3 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/flex-falcon/blob/285da92d/compiler.jx/src/org/apache/flex/compiler/internal/codegen/mxml/flexjs/MXMLFlexJSPublisher.java
----------------------------------------------------------------------
diff --git a/compiler.jx/src/org/apache/flex/compiler/internal/codegen/mxml/flexjs/MXMLFlexJSPublisher.java b/compiler.jx/src/org/apache/flex/compiler/internal/codegen/mxml/flexjs/MXMLFlexJSPublisher.java
index 050df56..ea423d7 100644
--- a/compiler.jx/src/org/apache/flex/compiler/internal/codegen/mxml/flexjs/MXMLFlexJSPublisher.java
+++ b/compiler.jx/src/org/apache/flex/compiler/internal/codegen/mxml/flexjs/MXMLFlexJSPublisher.java
@@ -60,7 +60,8 @@ public class MXMLFlexJSPublisher extends JSGoogPublisher implements
 
         this.isMarmotinniRun = ((JSGoogConfiguration) configuration)
                 .getMarmotinni() != null;
-
+        this.outputPathParameter = ((JSGoogConfiguration) configuration)
+                .getOutput();
         this.useStrictPublishing = ((JSGoogConfiguration) configuration)
                 .getStrictPublish();
 
@@ -70,18 +71,25 @@ public class MXMLFlexJSPublisher extends JSGoogPublisher implements
     private FlexJSProject project;
 
     private boolean isMarmotinniRun;
+    private String outputPathParameter;
     private boolean useStrictPublishing;
 
     @Override
     public File getOutputFolder()
     {
         // (erikdebruin) If there is a -marmotinni switch, we want
         //               the output redirected to the directory it specifies.
         if (isMarmotinniRun)
         {
             outputParentFolder = new File(
                     ((JSGoogConfiguration) configuration).getMarmotinni());
         }
+        else if (outputPathParameter != null)
+        {
+            outputParentFolder = new File(outputPathParameter);
+        }
         else
         {
             outputParentFolder = new File(
@@ -70,18 +71,25 @@ public class MXMLFlexJSPublisher extends JSGoogPublisher implements
     public File getOutputFolder()
     {
-        // (erikdebruin) If there is a -marmotinni switch, we want
-        //               the output redirected to the directory it specifies.
+        // (erikdebruin) - If there is a -marmotinni switch, we want
+        //                 the output redirected to the directory it specifies.
+        //               - If there is an -output switch, use that path as the 
+        //                 output parent folder.
         if (isMarmotinniRun)
         {